==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/krita/plugins/extensions/dockers/specificcolorselector/kis_color_input.h <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _KIS_COLOR_INPUT_H_
#define _KIS_COLOR_INPUT_H_

#include <QWidget>

class KoChannelInfo;
class KoColor;
class QWidget;
class KNumInput;
class QSpinBox;
class KDoubleNumInput;
class KoColorSlider;
class QLabel;
class QHBoxLayout;
class QLineEdit;

class KisColorInput : public QWidget
{
    Q_OBJECT
public:
    KisColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color);
protected:
    void init();
    virtual QWidget* createInput() = 0;
signals:
    void updated();
protected:
    const KoChannelInfo* m_channelInfo;
    KoColor* m_color;
    KoColorSlider* m_colorSlider;
};

class KisIntegerColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisIntegerColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue(int);
    void update();
private:
    QSpinBox* m_intNumInput;
};


class KisFloatColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisFloatColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue(double);
    void sliderChanged(int);
    void update();
private:
    KDoubleNumInput* m_dblNumInput;
};

class KisHexColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisHexColorInput(QWidget* parent, KoColor* color);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue();
    void update();
private:
    QLineEdit* m_hexInput;
};

#endif

==> calligra_2.8.90.orig.tar.xz: calligra-2.8.90/krita/plugins/extensions/dockers/specificcolorselector/kis_color_input.h <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _KIS_COLOR_INPUT_H_
#define _KIS_COLOR_INPUT_H_

#include <QWidget>

class KoChannelInfo;
class KoColor;
class QWidget;
class KNumInput;
class QSpinBox;
class KDoubleNumInput;
class KoColorSlider;
class QLabel;
class QHBoxLayout;
class QLineEdit;
#include "KoColorDisplayRendererInterface.h"


class KisColorInput : public QWidget
{
    Q_OBJECT
public:
    KisColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color, KoColorDisplayRendererInterface *displayRenderer);
protected:
    void init();
    virtual QWidget* createInput() = 0;
signals:
    void updated();
protected:
    const KoChannelInfo* m_channelInfo;
    KoColor* m_color;
    KoColorSlider* m_colorSlider;
    KoColorDisplayRendererInterface *m_displayRenderer;
};

class KisIntegerColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisIntegerColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color, KoColorDisplayRendererInterface *displayRenderer);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue(int);
    void update();
private:
    QSpinBox* m_intNumInput;
};


class KisFloatColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisFloatColorInput(QWidget* parent, const KoChannelInfo*, KoColor* color, KoColorDisplayRendererInterface *displayRenderer);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue(double);
    void sliderChanged(int);
    void update();
private:
    KDoubleNumInput* m_dblNumInput;
    qreal m_minValue;
    qreal m_maxValue;
};

class KisHexColorInput : public KisColorInput
{
    Q_OBJECT
public:
    KisHexColorInput(QWidget* parent, KoColor* color, KoColorDisplayRendererInterface *displayRenderer);
protected:
    virtual QWidget* createInput();
public slots:
    void setValue();
    void update();
private:
    QLineEdit* m_hexInput;
};

#endif
